@@ -5,7 +5,11 @@ SELECT DISTINCT
 	ss_users.first_name,
 	ss_users.last_name,
 	ss_users.login,
-	ss_users.password
+	ss_users.password,
+	ss_users.enabled,
+		ss_users.email_notify,
+		ss_users.field1 AS title,
+		ss_users.field4 AS address_1
 
 FROM
 	`ss_users`,
@@ -21,4 +25,8 @@ WHERE
 	ss_users.first_name,
 	ss_users.last_name,
 	ss_users.login,
-	ss_users.password
\ No newline at end of file
+	ss_users.password,
+	ss_users.enabled,
+		ss_users.email_notify,
+		ss_users.field1,
+		ss_users.field4
